@@ -3,5 +3,5 @@ use system_config::Config;
 fn main() {
     let mut config = Config::new("system-config-example").unwrap();
 
-    config.clear().unwrap();
+    config.write_clear().unwrap();
 }
\ No newline at end of file
